### Name: rsf
### Title: Random Survival Forests Primary R Function
### Aliases: rsf
### Keywords: survival tree

### ** Examples

# Example 1:  Minimal argument call using included sample data set.
data(veteran, package = "randomSurvivalForest")
veteran.out <- rsf(Survrsf(time, status)~., data = veteran)
print.rsf(veteran.out)
plot.error(veteran.out)

# Example 2:  Full argument call using included sample data set.
veteran.f <- as.formula(Survrsf(time, status)~.)
data(veteran)
ntree <- 100
mtry <- 2
nodesize <- 3
ntime <- NULL
splitrule <- "logrank"
proximity <- FALSE
seed <- -1
ntime.upper <- 1000
trace <- TRUE
veteran2.out <- rsf(veteran.f, veteran, ntree, mtry, nodesize,
                    ntime, splitrule, proximity, seed, ntime.upper, trace)
print.rsf(veteran2.out)

# Example 3:  Veteran's Administration lung cancer trial from
#  Kalbfleisch & Prentice.  Randomized trial of two treatment
#  regimens for lung cancer.  Assumes "survival"
#  library is loaded.  This is a standard survival analysis
#  data set, included in the package.

if (library("survival", logical.return = TRUE))
{
        data(veteran, package = "randomSurvivalForest")
        veteran3.out <- rsf(Survrsf(time, status)~ celltype,
                       veteran,
                       ntree = 1000)
        plot.ensemble(veteran3.out)
        par(mfrow = c(1,1))
        plot(survfit(Surv(time, status) ~ celltype, data = veteran))
}

# Example 4:  Primary biliary cirrhosis (PBC) of the liver.
#  Data found in Appendix D.1 of Fleming and Harrington, Counting
#  Processes and Survival Analysis, Wiley, 1991 (only differences
#  are that age is in days and sex and stage variables are not
#  missing for observations 313-418).  This is a sample data
#  set included in the package.

data(pbc, package = "randomSurvivalForest") 
pbc.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000)
print.rsf(pbc.out)
plot.variable(pbc.out)  ### par(ask = TRUE) might be useful here

# Example 5:  Compare Cox regression to Random Survival Forests
#  using the PBC data.  Compute OOB estimate of Harrell's
#  concordance index (B = 100).  Assumes "Hmisc" and "survival"
#  libraries are loaded. 

if (library("survival",logical.return = TRUE) 
    & library("Hmisc",logical.return = TRUE))
{
    data(pbc, package = "randomSurvivalForest")
    pbc2.out <- rsf(Survrsf(days,status)~., pbc, mtry = 2, ntree = 1000)
    B <- 100 
    cox.err <- 0 
    cox.f <- as.formula(Surv(days,status)~.)  
    pbc.data <- pbc[apply(is.na(pbc), 1, sum) == 0,] ##remove NA's 
    cat("Out-of-bag Cox Analysis ...", "\n")
    for (b in 1:B){
        cat("Cox bootstrap", b, "\n") 
        bag.sample <- sample(1:dim(pbc.data)[1],
                             dim(pbc.data)[1],
                             replace = TRUE) 
        oob.sample <- setdiff(1:dim(pbc.data)[1],bag.sample)
        train <- pbc.data[bag.sample,]
        test <- pbc.data[oob.sample,]
        cox.out <- coxph(cox.f, train)
        cox.predict <- predict(cox.out, test)
        cox.err <- cox.err +
             rcorr.cens(cox.predict, 
                  Surv(pbc.data$days[oob.sample],
                  pbc.data$status[oob.sample])
                 )[1]
     }
     cat("Error rates:", "\n")
     cat("Random Survival Forests:",
         pbc2.out$err.rate[pbc2.out$ntree],
         "\n")
     cat("         Cox Regression:", cox.err[1]/B, "\n")
}

# Example 6:  Using an external data set.
    ## Not run: 
##D         file.in <- "other.data"
##D         other.data <- read.table(file.in, header = TRUE)
##D 
##D         rsf.f <- as.formula(Survrsf(time, status)~.)
##D         rsf.out <- rsf(formula = rsf.f, data = other.data) 
##D     
## End(Not run)



